// CTEAM 039

#include <cstdio>
#include <cstddef>
#include <limits.h>

#include <map>

#define MAX 31000
#define MAXMAX (MAX*MAX)

int gcd(int a, int b ) {
    int t;
    if( b > a ) {
        t = a;
        a = b;
        b = t;
    }
        
    while ( b != 0 ) {
        t = b;
        b = a % b;
        a = t;
    }
    return a;
}

int makehash(int x, int y) {
    return ( ((x & 0xffff) << 16) | ( y & 0xffff ) );
}

struct Line { 
    int x1, y1, x2, y2;

    Line() {
    }

    Line ( int x1, int y1, int x2, int y2 ) {
        this->x1 = x1;
        this->y1 = y1;
        this->x2 = x2;
        this->y2 = y2;
    }
};

struct Picture {
    std::multimap<int,Line*> lines;
    int offsetx, offsety;

    Picture() {
        offsetx = offsety = 0;
    }

    void addLine(int x, int y, int lx, int ly) {
        if( lx < 0 ) {
            lx = -lx;
            ly = -ly;
            x -= lx;
            y -= ly;
        } else if( lx == 0 && ly < 0 ) {
            ly = -ly;
            y -= ly;
        }

        int ddd = gcd(lx < 0 ? -lx : lx, ly < 0 ? -ly : ly);
        int dx = lx / ddd;
        int dy = ly / ddd;
        int x1 = x;
        int y1 = y;
        int x2 = x + lx;
        int y2 = y + ly;
        int linehash = makehash(dx,dy);

//        printf("adding line: %d     %d %d    %d %d  %d %d\n", linehash, dx, dy, lx, ly, x1, y1);

        Line *line = new Line(x1,y1,x2,y2), *line2;
        std::multimap<int,Line*>::iterator it;
    DO_REPEAT:
        it = lines.find( linehash );
        while( it != lines.end() && it->first == linehash ) {
            line2 = it->second;
            bool mergethem = false;
            if( line2->x1 <= line->x2 && line2->x2 >= line->x1 ) {
                line->x1 = std::min( line->x1, line2->x1 );
                line->x2 = std::max( line->x2, line2->x2 );
                lines.erase(it);
                goto DO_REPEAT;
            }
        }
        lines.insert( std::pair<int,Line*>(linehash, line) );
    }

    void printlines()  const{
        printf("line\n");
        for( std::multimap<int,Line*>::const_iterator it = lines.begin(); it != lines.end(); it ++ ) {
            Line *l = it->second;
            printf("%d %d ...  %d %d\n",l->x1, l->y1,l->x2, l->y2);
        }
    }

    bool operator==( const Picture &b ) {
        this->printlines();
        b.printlines();
       std::multimap<int,Line*>::const_iterator it = this->lines.begin();
       std::multimap<int,Line*>::const_iterator it2 = b.lines.begin();

       while( it != this->lines.end() && it2 != b.lines.end() ) {
           Line *la = it->second, *lb = it2->second;

           if( la->x1 + offsetx != lb->x1 + b.offsetx )
               return false;
           if( la->x2 + offsetx != lb->x2 + b.offsetx )
               return false;
           if( la->y1 + offsety != lb->y1 + b.offsety )
               return false;
           if( la->y2 + offsety != lb->y2 + b.offsety )
               return false;
       }

        return it == this->lines.end() && it2 ==  b.lines.end();
    }
};

void loadOptimize(int N, Picture *p) {
    int X = 0, Y = 0;
    int minX = INT_MAX, minY=INT_MAX; // TODO

    char cmd;
    int cx, cy;

    for( int i = 0; i < N; i++ ) {
        getc( stdin );

        scanf( "%c %d %d", &cmd, &cx, &cy );
        if( cmd == 'L' ) {
            p->addLine( X, Y, cx, cy );
        }
        X += cx;
        Y += cy;
    }
}

int main() {
    int N;

    while( scanf("%d", &N ) == 1 ) {
        Picture *pa = new Picture,* pb = new Picture;
        loadOptimize(N,pa);
        scanf("%d", &N ) ;
        loadOptimize(N,pb);

        if( (*pa) == (*pb) ) {
            printf( "YES\n" );
        } else
            printf( "NO\n" );
    }
    return 0;
}
